print("import: 'CoreServices'")
import CoreServices

print("import: 'CoreServices.CarbonCore'")
import CoreServices.CarbonCore

print("import: 'CoreServices.DictionaryServices'")
import CoreServices.DictionaryServices

print("import: 'CoreServices.LaunchServices'")
import CoreServices.LaunchServices

print("import: 'CoreServices.Metadata'")
import CoreServices.Metadata

print("import: 'CoreServices.SearchKit'")
import CoreServices.SearchKit

