# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 18:46:06 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$$"""
misc.update({})
misc.update({})
functions = {
    "DCSDictionaryGetTypeID": (
        b"l",
        "",
        {"comment": "Function not present in header files"},
    ),
    "DCSGetTermRangeInString": (b"{_CFRange=qq}^{__DCSDictionary=}^{__CFString=}q",),
    "DCSCopyTextDefinition": (
        b"^{__CFString=}^{__DCSDictionary=}^{__CFString=}{_CFRange=qq}",
        "",
        {"retval": {"already_retained": True, "already_cfretained": True}},
    ),
}
cftypes = [("DCSDictionaryRef", b"^{__DCSDictionary=}", "DCSDictionaryGetTypeID", None)]
expressions = {}

# END OF FILE
